@@ -14,30 +14,30 @@
 
 #include "ktoolbar.h"
 
-#include <QPointer>
 #include <QAction>
+#include <QActionGroup>
 #include <QApplication>
-#include <QDesktopWidget>
+#include <QDomElement>
+#include <QDrag>
 #include <QFrame>
 #include <QLayout>
 #include <QMenu>
 #include <QMimeData>
-#include <QDrag>
 #include <QMouseEvent>
-#include <QDomElement>
+#include <QPointer>
 #ifdef QT_DBUS_LIB
 #include <QDBusConnection>
 #include <QDBusMessage>
 #endif
 
-#include <kauthorized.h>
-#include <kconfig.h>
-#include <ksharedconfig.h>
-#include <kicontheme.h>
-#include <klocalizedstring.h>
-#include <kstandardaction.h>
-#include <ktoggleaction.h>
-#include <kconfiggroup.h>
+#include <KAuthorized>
+#include <KConfig>
+#include <KConfigGroup>
+#include <KIconTheme>
+#include <KLocalizedString>
+#include <KSharedConfig>
+#include <KStandardAction>
+#include <KToggleAction>
 
 #include "kactioncollection.h"
 #include "kedittoolbar.h"
@@ -72,39 +72,37 @@
  on a given toolbar depends on whether there are settings at Level_AppXML or Level_UserSettings.
  Only if there are no settings at those levels, should the change of KDEDefault make a difference.
 */
-enum SettingLevel { Level_KDEDefault, Level_AppXML, Level_UserSettings,
-                    NSettingLevels
-                  };
+enum SettingLevel { Level_KDEDefault, Level_AppXML, Level_UserSettings, NSettingLevels };
 enum { Unset = -1 };
 
-class Q_DECL_HIDDEN KToolBar::Private
+class KToolBarPrivate
 {
 public:
-    Private(KToolBar *qq)
-        : q(qq),
-          isMainToolBar(false),
+    KToolBarPrivate(KToolBar *qq)
+        : q(qq)
+        , isMainToolBar(false)
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
-          enableContext(true),
+        , enableContext(true)
 #endif
-          unlockedMovable(true),
-          contextOrient(nullptr),
-          contextMode(nullptr),
-          contextSize(nullptr),
-          contextButtonTitle(nullptr),
-          contextShowText(nullptr),
-          contextButtonAction(nullptr),
-          contextTop(nullptr),
-          contextLeft(nullptr),
-          contextRight(nullptr),
-          contextBottom(nullptr),
-          contextIcons(nullptr),
-          contextTextRight(nullptr),
-          contextText(nullptr),
-          contextTextUnder(nullptr),
-          contextLockAction(nullptr),
-          dropIndicatorAction(nullptr),
-          context(nullptr),
-          dragAction(nullptr)
+        , unlockedMovable(true)
+        , contextOrient(nullptr)
+        , contextMode(nullptr)
+        , contextSize(nullptr)
+        , contextButtonTitle(nullptr)
+        , contextShowText(nullptr)
+        , contextButtonAction(nullptr)
+        , contextTop(nullptr)
+        , contextLeft(nullptr)
+        , contextRight(nullptr)
+        , contextBottom(nullptr)
+        , contextIcons(nullptr)
+        , contextTextRight(nullptr)
+        , contextText(nullptr)
+        , contextTextUnder(nullptr)
+        , contextLockAction(nullptr)
+        , dropIndicatorAction(nullptr)
+        , context(nullptr)
+        , dragAction(nullptr)
     {
     }
 
@@ -138,7 +136,7 @@ public:
     static Qt::ToolBarArea positionFromString(const QString &position);
     static Qt::ToolButtonStyle toolButtonStyleSetting();
 
-    KToolBar *q;
+    KToolBar *const q;
     bool isMainToolBar : 1;
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
     bool enableContext : 1;
@@ -210,6 +208,7 @@ public:
         {
             return values[index];
         }
+
     private:
         int values[NSettingLevels];
     };
@@ -224,10 +223,10 @@ public:
     QPoint dragStartPosition;
 };
 
-bool KToolBar::Private::s_editable = false;
-bool KToolBar::Private::s_locked = true;
+bool KToolBarPrivate::s_editable = false;
+bool KToolBarPrivate::s_locked = true;
 
-void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
+void KToolBarPrivate::init(bool readConfig, bool _isMainToolBar)
 {
     isMainToolBar = _isMainToolBar;
     loadKDESettings();
@@ -240,16 +239,11 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
 
     if (q->mainWindow()) {
         // Get notified when settings change
-        connect(q, &QToolBar::allowedAreasChanged,
-                q->mainWindow(), &KMainWindow::setSettingsDirty);
-        connect(q, &QToolBar::iconSizeChanged,
-                q->mainWindow(), &KMainWindow::setSettingsDirty);
-        connect(q, &QToolBar::toolButtonStyleChanged,
-                q->mainWindow(), &KMainWindow::setSettingsDirty);
-        connect(q, &QToolBar::movableChanged,
-                q->mainWindow(), &KMainWindow::setSettingsDirty);
-        connect(q, &QToolBar::orientationChanged,
-                q->mainWindow(), &KMainWindow::setSettingsDirty);
+        QObject::connect(q, &QToolBar::allowedAreasChanged, q->mainWindow(), &KMainWindow::setSettingsDirty);
+        QObject::connect(q, &QToolBar::iconSizeChanged, q->mainWindow(), &KMainWindow::setSettingsDirty);
+        QObject::connect(q, &QToolBar::toolButtonStyleChanged, q->mainWindow(), &KMainWindow::setSettingsDirty);
+        QObject::connect(q, &QToolBar::movableChanged, q->mainWindow(), &KMainWindow::setSettingsDirty);
+        QObject::connect(q, &QToolBar::orientationChanged, q->mainWindow(), &KMainWindow::setSettingsDirty);
     }
 
     if (!KAuthorized::authorize(QStringLiteral("movable_toolbars"))) {
@@ -260,20 +254,20 @@ void KToolBar::Private::init(bool readConfig, bool _isMainToolBar)
 
     q->toggleViewAction()->setEnabled(KAuthorized::authorizeAction(QStringLiteral("options_show_toolbar")));
 
-    connect(q, &QToolBar::movableChanged,
-            q, &KToolBar::slotMovableChanged);
+    QObject::connect(q, &QToolBar::movableChanged, q, &KToolBar::slotMovableChanged);
 
     q->setAcceptDrops(true);
 
 #ifdef QT_DBUS_LIB
-    QDBusConnection::sessionBus().connect(QString(), QStringLiteral("/KToolBar"), QStringLiteral("org.kde.KToolBar"),
-                                          QStringLiteral("styleChanged"), q, SLOT(slotAppearanceChanged()));
+    QDBusConnection::sessionBus()
+        .connect(QString(), QStringLiteral("/KToolBar"), QStringLiteral("org.kde.KToolBar"), QStringLiteral("styleChanged"), q, SLOT(slotAppearanceChanged()));
 #endif
-    connect(KIconLoader::global(), SIGNAL(iconLoaderSettingsChanged()),
-            q, SLOT(slotAppearanceChanged()));
+    QObject::connect(KIconLoader::global(), &KIconLoader::iconLoaderSettingsChanged, q, [this]() {
+        slotAppearanceChanged();
+    });
 }
 
-QString KToolBar::Private::getPositionAsString() const
+QString KToolBarPrivate::getPositionAsString() const
 {
     // get all of the stuff to save
     switch (q->mainWindow()->toolBarArea(const_cast<KToolBar *>(q))) {
@@ -289,23 +283,33 @@ QString KToolBar::Private::getPositionAsString() const
     }
 }
 
-QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
+QMenu *KToolBarPrivate::contextMenu(const QPoint &globalPos)
 {
     if (!context) {
         context = new QMenu(q);
 
         contextButtonTitle = context->addSection(i18nc("@title:menu", "Show Text"));
-        contextShowText = context->addAction(QString(), q, SLOT(slotContextShowText()));
+        contextShowText = context->addAction(QString(), q, [this]() {
+            slotContextShowText();
+        });
 
         context->addSection(i18nc("@title:menu", "Toolbar Settings"));
 
         contextOrient = new QMenu(i18nc("Toolbar orientation", "Orientation"), context);
 
-        contextTop = contextOrient->addAction(i18nc("toolbar position string", "Top"), q, SLOT(slotContextTop()));
+        contextTop = contextOrient->addAction(i18nc("toolbar position string", "Top"), q, [this]() {
+            slotContextTop();
+        });
         contextTop->setChecked(true);
-        contextLeft = contextOrient->addAction(i18nc("toolbar position string", "Left"), q, SLOT(slotContextLeft()));
-        contextRight = contextOrient->addAction(i18nc("toolbar position string", "Right"), q, SLOT(slotContextRight()));
-        contextBottom = contextOrient->addAction(i18nc("toolbar position string", "Bottom"), q, SLOT(slotContextBottom()));
+        contextLeft = contextOrient->addAction(i18nc("toolbar position string", "Left"), q, [this]() {
+            slotContextLeft();
+        });
+        contextRight = contextOrient->addAction(i18nc("toolbar position string", "Right"), q, [this]() {
+            slotContextRight();
+        });
+        contextBottom = contextOrient->addAction(i18nc("toolbar position string", "Bottom"), q, [this]() {
+            slotContextBottom();
+        });
 
         QActionGroup *positionGroup = new QActionGroup(contextOrient);
         const auto orientActions = contextOrient->actions();
@@ -316,10 +320,18 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
 
         contextMode = new QMenu(i18n("Text Position"), context);
 
-        contextIcons = contextMode->addAction(i18nc("@item:inmenu", "Icons Only"), q, SLOT(slotContextIcons()));
-        contextText = contextMode->addAction(i18nc("@item:inmenu", "Text Only"), q, SLOT(slotContextText()));
-        contextTextRight = contextMode->addAction(i18nc("@item:inmenu", "Text Alongside Icons"), q, SLOT(slotContextTextRight()));
-        contextTextUnder = contextMode->addAction(i18nc("@item:inmenu", "Text Under Icons"), q, SLOT(slotContextTextUnder()));
+        contextIcons = contextMode->addAction(i18nc("@item:inmenu", "Icons Only"), q, [this]() {
+            slotContextIcons();
+        });
+        contextText = contextMode->addAction(i18nc("@item:inmenu", "Text Only"), q, [this]() {
+            slotContextText();
+        });
+        contextTextRight = contextMode->addAction(i18nc("@item:inmenu", "Text Alongside Icons"), q, [this]() {
+            slotContextTextRight();
+        });
+        contextTextUnder = contextMode->addAction(i18nc("@item:inmenu", "Text Under Icons"), q, [this]() {
+            slotContextTextUnder();
+        });
 
         QActionGroup *textGroup = new QActionGroup(contextMode);
         const auto modeActions = contextMode->actions();
@@ -330,8 +342,12 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
 
         contextSize = new QMenu(i18n("Icon Size"), context);
 
-        contextIconSizes.insert(contextSize->addAction(i18nc("@item:inmenu Icon size", "Default"), q, SLOT(slotContextIconSize())),
-                                iconSizeSettings.defaultValue());
+        auto contextIconSizeFunc = [this]() {
+            slotContextIconSize();
+        };
+
+        auto *act = contextSize->addAction(i18nc("@item:inmenu Icon size", "Default"), q, contextIconSizeFunc);
+        contextIconSizes.insert(act, iconSizeSettings.defaultValue());
 
         // Query the current theme for available sizes
         KIconTheme *theme = KIconLoader::global()->theme();
@@ -344,7 +360,7 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
 
         if (avSizes.count() < 10) {
             // Fixed or threshold type icons
-            for (int it : qAsConst(avSizes)) {
+            for (int it : std::as_const(avSizes)) {
                 QString text;
                 if (it < 19) {
                     text = i18n("Small (%1x%2)", it, it);
@@ -357,14 +373,14 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
                 }
 
                 // save the size in the contextIconSizes map
-                contextIconSizes.insert(contextSize->addAction(text, q, SLOT(slotContextIconSize())), it);
+                contextIconSizes.insert(contextSize->addAction(text, q, contextIconSizeFunc), it);
             }
         } else {
             // Scalable icons.
-            const int progression[] = { 16, 22, 32, 48, 64, 96, 128, 192, 256 };
+            const int progression[] = {16, 22, 32, 48, 64, 96, 128, 192, 256};
 
             for (int p : progression) {
-                for (int it : qAsConst(avSizes)) {
+                for (int it : std::as_const(avSizes)) {
                     if (it >= p) {
                         QString text;
                         if (it < 19) {
@@ -378,7 +394,7 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
                         }
 
                         // save the size in the contextIconSizes map
-                        contextIconSizes.insert(contextSize->addAction(text, q, SLOT(slotContextIconSize())), it);
+                        contextIconSizes.insert(contextSize->addAction(text, q, contextIconSizeFunc), it);
                         break;
                     }
                 }
@@ -399,7 +415,9 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
         delete contextLockAction;
         contextLockAction = new KToggleAction(QIcon::fromTheme(QStringLiteral("system-lock-screen")), i18n("Lock Toolbar Positions"), q);
         contextLockAction->setChecked(q->toolBarsLocked());
-        connect(contextLockAction, SIGNAL(toggled(bool)), q, SLOT(slotLockToolBars(bool)));
+        QObject::connect(contextLockAction, &KToggleAction::toggled, q, [this](bool checked) {
+            slotLockToolBars(checked);
+        });
 
         // Now add the actions to the menu
         context->addMenu(contextMode);
@@ -407,7 +425,9 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
         context->addMenu(contextOrient);
         context->addSeparator();
 
-        connect(context, SIGNAL(aboutToShow()), q, SLOT(slotContextAboutToShow()));
+        QObject::connect(context, &QMenu::aboutToShow, q, [this]() {
+            slotContextAboutToShow();
+        });
     }
 
     contextButtonAction = q->actionAt(q->mapFromGlobal(globalPos));
@@ -420,19 +440,19 @@ QMenu *KToolBar::Private::contextMenu(const QPoint &globalPos)
     contextOrient->menuAction()->setVisible(!q->toolBarsLocked());
     // Unplugging a submenu from abouttohide leads to the popupmenu floating around
     // So better simply call that code from after exec() returns (DF)
-    //connect(context, SIGNAL(aboutToHide()), this, SLOT(slotContextAboutToHide()));
+    // connect(context, SIGNAL(aboutToHide()), this, SLOT(slotContextAboutToHide()));
 
     return context;
 }
 
-void KToolBar::Private::setLocked(bool locked)
+void KToolBarPrivate::setLocked(bool locked)
 {
     if (unlockedMovable) {
         q->setMovable(!locked);
     }
 }
 
-void KToolBar::Private::adjustSeparatorVisibility()
+void KToolBarPrivate::adjustSeparatorVisibility()
 {
     bool visibleNonSeparator = false;
     int separatorToShow = -1;
@@ -462,7 +482,7 @@ void KToolBar::Private::adjustSeparatorVisibility()
     }
 }
 
-Qt::ToolButtonStyle KToolBar::Private::toolButtonStyleFromString(const QString &_style)
+Qt::ToolButtonStyle KToolBarPrivate::toolButtonStyleFromString(const QString &_style)
 {
     QString style = _style.toLower();
     if (style == QLatin1String("textbesideicon") || style == QLatin1String("icontextright")) {
@@ -476,7 +496,7 @@ Qt::ToolButtonStyle KToolBar::Private::toolButtonStyleFromString(const QString &
     }
 }
 
-QString KToolBar::Private::toolButtonStyleToString(Qt::ToolButtonStyle style)
+QString KToolBarPrivate::toolButtonStyleToString(Qt::ToolButtonStyle style)
 {
     switch (style) {
     case Qt::ToolButtonIconOnly:
@@ -491,7 +511,7 @@ QString KToolBar::Private::toolButtonStyleToString(Qt::ToolButtonStyle style)
     }
 }
 
-Qt::ToolBarArea KToolBar::Private::positionFromString(const QString &position)
+Qt::ToolBarArea KToolBarPrivate::positionFromString(const QString &position)
 {
     Qt::ToolBarArea newposition = Qt::TopToolBarArea;
     if (position == QLatin1String("left")) {
@@ -505,20 +525,20 @@ Qt::ToolBarArea KToolBar::Private::positionFromString(const QString &position)
 }
 
 // Global setting was changed
-void KToolBar::Private::slotAppearanceChanged()
+void KToolBarPrivate::slotAppearanceChanged()
 {
     loadKDESettings();
     applyCurrentSettings();
 }
 
-Qt::ToolButtonStyle KToolBar::Private::toolButtonStyleSetting()
+Qt::ToolButtonStyle KToolBarPrivate::toolButtonStyleSetting()
 {
     KConfigGroup group(KSharedConfig::openConfig(), "Toolbar style");
-    const QString fallback = KToolBar::Private::toolButtonStyleToString(Qt::ToolButtonTextBesideIcon);
-    return KToolBar::Private::toolButtonStyleFromString(group.readEntry("ToolButtonStyle", fallback));
+    const QString fallback = KToolBarPrivate::toolButtonStyleToString(Qt::ToolButtonTextBesideIcon);
+    return KToolBarPrivate::toolButtonStyleFromString(group.readEntry("ToolButtonStyle", fallback));
 }
 
-void KToolBar::Private::loadKDESettings()
+void KToolBarPrivate::loadKDESettings()
 {
     iconSizeSettings[Level_KDEDefault] = q->iconSizeDefault();
 
@@ -543,17 +563,18 @@ void KToolBar::Private::loadKDESettings()
 
         KConfigGroup group(KSharedConfig::openConfig(), "Toolbar style");
         const QString value = group.readEntry("ToolButtonStyleOtherToolbars", fallBack);
-        toolButtonStyleSettings[Level_KDEDefault] = KToolBar::Private::toolButtonStyleFromString(value);
+        toolButtonStyleSettings[Level_KDEDefault] = KToolBarPrivate::toolButtonStyleFromString(value);
     }
 }
 
 // Call this after changing something in d->iconSizeSettings or d->toolButtonStyleSettings
-void KToolBar::Private::applyCurrentSettings()
+void KToolBarPrivate::applyCurrentSettings()
 {
-    //qCDebug(DEBUG_KXMLGUI) << q->objectName() << "iconSizeSettings:" << iconSizeSettings.toString() << "->" << iconSizeSettings.currentValue();
+    // qCDebug(DEBUG_KXMLGUI) << q->objectName() << "iconSizeSettings:" << iconSizeSettings.toString() << "->" << iconSizeSettings.currentValue();
     const int currentIconSize = iconSizeSettings.currentValue();
     q->setIconSize(QSize(currentIconSize, currentIconSize));
-    //qCDebug(DEBUG_KXMLGUI) << q->objectName() << "toolButtonStyleSettings:" << toolButtonStyleSettings.toString() << "->" << toolButtonStyleSettings.currentValue();
+    // qCDebug(DEBUG_KXMLGUI) << q->objectName() << "toolButtonStyleSettings:" << toolButtonStyleSettings.toString() << "->" <<
+    // toolButtonStyleSettings.currentValue();
     q->setToolButtonStyle(static_cast<Qt::ToolButtonStyle>(toolButtonStyleSettings.currentValue()));
 
     // And remember to save the new look later
@@ -563,7 +584,7 @@ void KToolBar::Private::applyCurrentSettings()
     }
 }
 
-QAction *KToolBar::Private::findAction(const QString &actionName, KXMLGUIClient **clientOut) const
+QAction *KToolBarPrivate::findAction(const QString &actionName, KXMLGUIClient **clientOut) const
 {
     for (KXMLGUIClient *client : xmlguiClients) {
         QAction *action = client->actionCollection()->action(actionName);
@@ -577,7 +598,7 @@ QAction *KToolBar::Private::findAction(const QString &actionName, KXMLGUIClient
     return nullptr;
 }
 
-void KToolBar::Private::slotContextAboutToShow()
+void KToolBarPrivate::slotContextAboutToShow()
 {
     /**
      * The idea here is to reuse the "static" part of the menu to save time.
@@ -632,7 +653,7 @@ void KToolBar::Private::slotContextAboutToShow()
         break;
     }
 
-    QMapIterator< QAction *, int > it = contextIconSizes;
+    QMapIterator<QAction *, int> it = contextIconSizes;
     while (it.hasNext()) {
         it.next();
         if (it.value() == q->iconSize().width()) {
@@ -657,9 +678,9 @@ void KToolBar::Private::slotContextAboutToShow()
         break;
     }
 
-    const bool showButtonSettings = contextButtonAction
-                                    && !contextShowText->text().isEmpty()
-                                    && contextTextRight->isChecked();
+    const bool showButtonSettings = contextButtonAction //
+        && !contextShowText->text().isEmpty() //
+        && contextTextRight->isChecked();
     contextButtonTitle->setVisible(showButtonSettings);
     contextShowText->setVisible(showButtonSettings);
     if (showButtonSettings) {
@@ -667,7 +688,7 @@ void KToolBar::Private::slotContextAboutToShow()
     }
 }
 
-void KToolBar::Private::slotContextAboutToHide()
+void KToolBarPrivate::slotContextAboutToHide()
 {
     // We have to unplug whatever slotContextAboutToShow plugged into the menu.
     // Unplug the toolbar menu action
@@ -694,21 +715,20 @@ void KToolBar::Private::slotContextAboutToHide()
     context->removeAction(contextLockAction);
 }
 
-void KToolBar::Private::slotContextLeft()
+void KToolBarPrivate::slotContextLeft()
 {
     q->mainWindow()->addToolBar(Qt::LeftToolBarArea, q);
 }
 
-void KToolBar::Private::slotContextRight()
+void KToolBarPrivate::slotContextRight()
 {
     q->mainWindow()->addToolBar(Qt::RightToolBarArea, q);
 }
 
-void KToolBar::Private::slotContextShowText()
+void KToolBarPrivate::slotContextShowText()
 {
     Q_ASSERT(contextButtonAction);
-    const QAction::Priority priority = contextShowText->isChecked()
-                                       ? QAction::NormalPriority : QAction::LowPriority;
+    const QAction::Priority priority = contextShowText->isChecked() ? QAction::NormalPriority : QAction::LowPriority;
     contextButtonAction->setPriority(priority);
 
     // Find to which xml file and componentData the action belongs to
@@ -735,41 +755,41 @@ void KToolBar::Private::slotContextShowText()
     KXMLGUIFactory::saveConfigFile(document, filename, componentName);
 }
 
-void KToolBar::Private::slotContextTop()
+void KToolBarPrivate::slotContextTop()
 {
     q->mainWindow()->addToolBar(Qt::TopToolBarArea, q);
 }
 
-void KToolBar::Private::slotContextBottom()
+void KToolBarPrivate::slotContextBottom()
 {
     q->mainWindow()->addToolBar(Qt::BottomToolBarArea, q);
 }
 
-void KToolBar::Private::slotContextIcons()
+void KToolBarPrivate::slotContextIcons()
 {
     q->setToolButtonStyle(Qt::ToolButtonIconOnly);
     toolButtonStyleSettings[Level_UserSettings] = q->toolButtonStyle();
 }
 
-void KToolBar::Private::slotContextText()
+void KToolBarPrivate::slotContextText()
 {
     q->setToolButtonStyle(Qt::ToolButtonTextOnly);
     toolButtonStyleSettings[Level_UserSettings] = q->toolButtonStyle();
 }
 
-void KToolBar::Private::slotContextTextUnder()
+void KToolBarPrivate::slotContextTextUnder()
 {
     q->setToolButtonStyle(Qt::ToolButtonTextUnderIcon);
     toolButtonStyleSettings[Level_UserSettings] = q->toolButtonStyle();
 }
 
-void KToolBar::Private::slotContextTextRight()
+void KToolBarPrivate::slotContextTextRight()
 {
     q->setToolButtonStyle(Qt::ToolButtonTextBesideIcon);
     toolButtonStyleSettings[Level_UserSettings] = q->toolButtonStyle();
 }
 
-void KToolBar::Private::slotContextIconSize()
+void KToolBarPrivate::slotContextIconSize()
 {
     QAction *action = qobject_cast<QAction *>(q->sender());
     if (action && contextIconSizes.contains(action)) {
@@ -778,14 +798,14 @@ void KToolBar::Private::slotContextIconSize()
     }
 }
 
-void KToolBar::Private::slotLockToolBars(bool lock)
+void KToolBarPrivate::slotLockToolBars(bool lock)
 {
     q->setToolBarsLocked(lock);
 }
 
 KToolBar::KToolBar(QWidget *parent, bool isMainToolBar, bool readConfig)
-    : QToolBar(parent),
-      d(new Private(this))
+    : QToolBar(parent)
+    , d(new KToolBarPrivate(this))
 {
     d->init(readConfig, isMainToolBar);
 
@@ -796,8 +816,8 @@ KToolBar::KToolBar(QWidget *parent, bool isMainToolBar, bool readConfig)
 }
 
 KToolBar::KToolBar(const QString &objectName, QWidget *parent, bool readConfig)
-    : QToolBar(parent),
-      d(new Private(this))
+    : QToolBar(parent)
+    , d(new KToolBarPrivate(this))
 {
     setObjectName(objectName);
     // mainToolBar -> isMainToolBar = true  -> buttonStyle is configurable
@@ -810,10 +830,9 @@ KToolBar::KToolBar(const QString &objectName, QWidget *parent, bool readConfig)
     }
 }
 
-KToolBar::KToolBar(const QString &objectName, QMainWindow *parent, Qt::ToolBarArea area,
-                   bool newLine, bool isMainToolBar, bool readConfig)
-    : QToolBar(parent),
-      d(new Private(this))
+KToolBar::KToolBar(const QString &objectName, QMainWindow *parent, Qt::ToolBarArea area, bool newLine, bool isMainToolBar, bool readConfig)
+    : QToolBar(parent)
+    , d(new KToolBarPrivate(this))
 {
     setObjectName(objectName);
     d->init(readConfig, isMainToolBar);
@@ -832,7 +851,6 @@ KToolBar::KToolBar(const QString &objectName, QMainWindow *parent, Qt::ToolBarAr
 KToolBar::~KToolBar()
 {
     delete d->contextLockAction;
-    delete d;
 }
 
 #if KXMLGUI_BUILD_DEPRECATED_SINCE(5, 0)
@@ -854,7 +872,7 @@ void KToolBar::saveSettings(KConfigGroup &cg)
     Q_ASSERT(!cg.name().isEmpty());
 
     const int currentIconSize = iconSize().width();
-    //qCDebug(DEBUG_KXMLGUI) << objectName() << currentIconSize << d->iconSizeSettings.toString() << "defaultValue=" << d->iconSizeSettings.defaultValue();
+    // qCDebug(DEBUG_KXMLGUI) << objectName() << currentIconSize << d->iconSizeSettings.toString() << "defaultValue=" << d->iconSizeSettings.defaultValue();
     if (!cg.hasDefault("IconSize") && currentIconSize == d->iconSizeSettings.defaultValue()) {
         cg.revertToDefault("IconSize");
         d->iconSizeSettings[Level_UserSettings] = Unset;
@@ -918,7 +936,7 @@ void KToolBar::loadState(const QDomElement &element)
     }
 
     {
-        const QString& i18nText = KToolbarHelper::i18nToolBarName(element);
+        const QString &i18nText = KToolbarHelper::i18nToolBarName(element);
         if (!i18nText.isEmpty()) {
             setWindowTitle(i18nText);
         }
@@ -989,7 +1007,7 @@ void KToolBar::loadState(const QDomElement &element)
     {
         QString attrPosition = element.attribute(QStringLiteral("position")).toLower();
         if (!attrPosition.isEmpty()) {
-            pos = KToolBar::Private::positionFromString(attrPosition);
+            pos = KToolBarPrivate::positionFromString(attrPosition);
         }
     }
     if (pos != Qt::NoToolBarArea) {
@@ -1077,8 +1095,8 @@ void KToolBar::slotMovableChanged(bool movable)
 
 void KToolBar::dragEnterEvent(QDragEnterEvent *event)
 {
-    if (toolBarsEditable() && event->proposedAction() & (Qt::CopyAction | Qt::MoveAction) &&
-            event->mimeData()->hasFormat(QStringLiteral("application/x-kde-action-list"))) {
+    if (toolBarsEditable() && event->proposedAction() & (Qt::CopyAction | Qt::MoveAction)
+        && event->mimeData()->hasFormat(QStringLiteral("application/x-kde-action-list"))) {
         QByteArray data = event->mimeData()->data(QStringLiteral("application/x-kde-action-list"));
 
         QDataStream stream(data);
@@ -1088,7 +1106,7 @@ void KToolBar::dragEnterEvent(QDragEnterEvent *event)
         stream >> actionNames;
 
         const auto allCollections = KActionCollection::allCollections();
-        for (const QString &actionName : qAsConst(actionNames)) {
+        for (const QString &actionName : std::as_const(actionNames)) {
             for (KActionCollection *ac : allCollections) {
                 QAction *newAction = ac->action(actionName);
                 if (newAction) {
@@ -1120,10 +1138,9 @@ void KToolBar::dragEnterEvent(QDragEnterEvent *event)
 
 void KToolBar::dragMoveEvent(QDragMoveEvent *event)
 {
-    if (toolBarsEditable())
+    if (toolBarsEditable()) {
         Q_FOREVER {
-        if (d->dropIndicatorAction)
-            {
+            if (d->dropIndicatorAction) {
                 QAction *overAction = nullptr;
                 const auto actions = this->actions();
                 for (QAction *action : actions) {
@@ -1154,13 +1171,14 @@ void KToolBar::dragMoveEvent(QDragMoveEvent *event)
             }
             break;
         }
+    }
 
     QToolBar::dragMoveEvent(event);
 }
 
 void KToolBar::dragLeaveEvent(QDragLeaveEvent *event)
 {
-    // Want to clear this even if toolBarsEditable was changed mid-drag (unlikey)
+    // Want to clear this even if toolBarsEditable was changed mid-drag (unlikely)
     delete d->dropIndicatorAction;
     d->dropIndicatorAction = nullptr;
     d->actionsBeingDragged.clear();
@@ -1176,7 +1194,7 @@ void KToolBar::dragLeaveEvent(QDragLeaveEvent *event)
 void KToolBar::dropEvent(QDropEvent *event)
 {
     if (toolBarsEditable()) {
-        for (QAction *action : qAsConst(d->actionsBeingDragged)) {
+        for (QAction *action : std::as_const(d->actionsBeingDragged)) {
             if (actions().contains(action)) {
                 removeAction(action);
             }
@@ -1184,7 +1202,7 @@ void KToolBar::dropEvent(QDropEvent *event)
         }
     }
 
-    // Want to clear this even if toolBarsEditable was changed mid-drag (unlikey)
+    // Want to clear this even if toolBarsEditable was changed mid-drag (unlikely)
     delete d->dropIndicatorAction;
     d->dropIndicatorAction = nullptr;
     d->actionsBeingDragged.clear();
@@ -1242,12 +1260,13 @@ void KToolBar::mouseMoveEvent(QMouseEvent *event)
 
     Qt::DropAction dropAction = drag->exec(Qt::MoveAction);
 
-    if (dropAction == Qt::MoveAction)
+    if (dropAction == Qt::MoveAction) {
         // Only remove from this toolbar if it was moved to another toolbar
         // Otherwise the receiver moves it.
         if (drag->target() != this) {
             removeAction(d->dragAction);
         }
+    }
 
     d->dragAction = nullptr;
     event->accept();
@@ -1255,7 +1274,7 @@ void KToolBar::mouseMoveEvent(QMouseEvent *event)
 
 void KToolBar::mouseReleaseEvent(QMouseEvent *event)
 {
-    // Want to clear this even if toolBarsEditable was changed mid-drag (unlikey)
+    // Want to clear this even if toolBarsEditable was changed mid-drag (unlikely)
     if (d->dragAction) {
         d->dragAction = nullptr;
         event->accept();
@@ -1270,11 +1289,13 @@ bool KToolBar::eventFilter(QObject *watched, QEvent *event)
     // Generate context menu events for disabled buttons too...
     if (event->type() == QEvent::MouseButtonPress) {
         QMouseEvent *me = static_cast<QMouseEvent *>(event);
-        if (me->buttons() & Qt::RightButton)
-            if (QWidget *ww = qobject_cast<QWidget *>(watched))
+        if (me->buttons() & Qt::RightButton) {
+            if (QWidget *ww = qobject_cast<QWidget *>(watched)) {
                 if (ww->parent() == this && !ww->isEnabled()) {
                     QCoreApplication::postEvent(this, new QContextMenuEvent(QContextMenuEvent::Mouse, me->pos(), me->globalPos()));
                 }
+            }
+        }
 
     } else if (event->type() == QEvent::ParentChange) {
         // Make sure we're not leaving stale event filters around,
@@ -1297,22 +1318,19 @@ bool KToolBar::eventFilter(QObject *watched, QEvent *event)
             switch (event->type()) {
             case QEvent::MouseButtonPress: {
                 QMouseEvent *me = static_cast<QMouseEvent *>(event);
-                QMouseEvent newEvent(me->type(), mapFromGlobal(ww->mapToGlobal(me->pos())), me->globalPos(),
-                                     me->button(), me->buttons(), me->modifiers());
+                QMouseEvent newEvent(me->type(), mapFromGlobal(ww->mapToGlobal(me->pos())), me->globalPos(), me->button(), me->buttons(), me->modifiers());
                 mousePressEvent(&newEvent);
                 return true;
             }
             case QEvent::MouseMove: {
                 QMouseEvent *me = static_cast<QMouseEvent *>(event);
-                QMouseEvent newEvent(me->type(), mapFromGlobal(ww->mapToGlobal(me->pos())), me->globalPos(),
-                                     me->button(), me->buttons(), me->modifiers());
+                QMouseEvent newEvent(me->type(), mapFromGlobal(ww->mapToGlobal(me->pos())), me->globalPos(), me->button(), me->buttons(), me->modifiers());
                 mouseMoveEvent(&newEvent);
                 return true;
             }
             case QEvent::MouseButtonRelease: {
                 QMouseEvent *me = static_cast<QMouseEvent *>(event);
-                QMouseEvent newEvent(me->type(), mapFromGlobal(ww->mapToGlobal(me->pos())), me->globalPos(),
-                                     me->button(), me->buttons(), me->modifiers());
+                QMouseEvent newEvent(me->type(), mapFromGlobal(ww->mapToGlobal(me->pos())), me->globalPos(), me->button(), me->buttons(), me->modifiers());
                 mouseReleaseEvent(&newEvent);
                 return true;
             }
@@ -1333,7 +1351,7 @@ void KToolBar::actionEvent(QActionEvent *event)
             widget->removeEventFilter(this);
 
             const auto children = widget->findChildren<QWidget *>();
-            for (QWidget *child : children)  {
+            for (QWidget *child : children) {
                 child->removeEventFilter(this);
             }
         }
@@ -1352,8 +1370,8 @@ void KToolBar::actionEvent(QActionEvent *event)
             }
             // Center widgets that do not have any use for more space. See bug 165274
             if (!(widget->sizePolicy().horizontalPolicy() & QSizePolicy::GrowFlag)
-                    // ... but do not center when using text besides icon in vertical toolbar. See bug 243196
-                    && !(orientation() == Qt::Vertical && toolButtonStyle() == Qt::ToolButtonTextBesideIcon)) {
+                // ... but do not center when using text besides icon in vertical toolbar. See bug 243196
+                && !(orientation() == Qt::Vertical && toolButtonStyle() == Qt::ToolButtonTextBesideIcon)) {
                 const int index = layout()->indexOf(widget);
                 if (index != -1) {
                     layout()->itemAt(index)->setAlignment(Qt::AlignJustify);
@@ -1367,20 +1385,20 @@ void KToolBar::actionEvent(QActionEvent *event)
 
 bool KToolBar::toolBarsEditable()
 {
-    return KToolBar::Private::s_editable;
+    return KToolBarPrivate::s_editable;
 }
 
 void KToolBar::setToolBarsEditable(bool editable)
 {
-    if (KToolBar::Private::s_editable != editable) {
-        KToolBar::Private::s_editable = editable;
+    if (KToolBarPrivate::s_editable != editable) {
+        KToolBarPrivate::s_editable = editable;
     }
 }
 
 void KToolBar::setToolBarsLocked(bool locked)
 {
-    if (KToolBar::Private::s_locked != locked) {
-        KToolBar::Private::s_locked = locked;
+    if (KToolBarPrivate::s_locked != locked) {
+        KToolBarPrivate::s_locked = locked;
 
         const auto windows = KMainWindow::memberList();
         for (KMainWindow *mw : windows) {
@@ -1394,7 +1412,7 @@ void KToolBar::setToolBarsLocked(bool locked)
 
 bool KToolBar::toolBarsLocked()
 {
-    return KToolBar::Private::s_locked;
+    return KToolBarPrivate::s_locked;
 }
 
 void KToolBar::emitToolbarStyleChanged()
